using HermesSocketServer.Models;
using ILogger = Serilog.ILogger;

namespace HermesSocketServer.Requests
{
    public class DeletePolicy : IRequest
    {
        public string Name => "delete_policy";
        public string[] RequiredKeys => ["id"];
        private ILogger _logger;

        public DeletePolicy(ILogger logger)
        {
            _logger = logger;
        }

        public Task<RequestResult> Grant(Channel channel, IDictionary<string, object> data)
        {
            string policyId = data["id"].ToString()!;
            var policy = channel.Policies.Get(policyId);
            if (policy != null) {
                channel.Policies.Remove(policyId);
                _logger.Information($"Deleted a policy by id [policy id: {data["id"]}]");
                return Task.FromResult(RequestResult.Successful(policy.GroupId + "/" + policy.Path));
            }

            _logger.Warning($"Failed to find policy by id [id: {policyId}]");
            return Task.FromResult(RequestResult.Failed("Policy ID does not exist."));
        }
    }
}